doapfiend.utils.NotFoundError

Package doapfiend :: Module utils :: Class NotFoundError |
[hide private]
[frames] | no frames]

# Class NotFoundError

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                                  NotFoundError

DOAP not found

Instance Methods | [hide private]
__init__(self, err_msg) Initialize attributes | source code
__str__(self) str(x) | source code
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, err_msg) (Constructor) | source code
Initialize attributes Overrides: object.__init__

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)